@@ -3,7 +3,9 @@ package Amazon::API::ECS;
 use strict;
 use warnings;
 
-use parent qw{ Amazon::API };
+use parent qw( Amazon::API );
+
+our $VERSION = '1.2.4';
 
 our @API_METHODS = qw{
   CreateCapacityProvider
@@ -70,8 +72,7 @@ sub new {
     { service     => 'ecs',
       api         => 'AmazonEC2ContainerServiceV20141113',
       api_methods => \@API_METHODS,
-      debug       => $ENV{DEBUG} // 0,
-      %options
+      %options,
     }
   );
 } ## end sub new
