@@ -3,7 +3,7 @@ package Amazon::API::Error;
 use strict;
 use warnings;
 
-use parent qw/Class::Accessor/;
+use parent qw( Class::Accessor );
 
 use English qw{ -no_match_vars };
 use JSON::PP qw{ decode_json };
@@ -13,7 +13,7 @@ use XML::LibXML::Simple qw{ XMLin };
 __PACKAGE__->follow_best_practice;
 __PACKAGE__->mk_accessors(qw/error api message_raw response content_type/);
 
-our $VERSION = '1.2.3';
+our $VERSION = '1.2.4';
 
 sub new {
   my ( $class, @options ) = @_;
@@ -76,7 +76,7 @@ __END__
 
 C<Amazon::API::Error>
 
-=head1 SYNOPIS
+=head1 SYNOPSIS
 
  my $result = eval {
    decode_json(
