@@ -3,7 +3,9 @@ package Amazon::SQS;
 use strict;
 use warnings;
 
-use parent qw{ Amazon::API };
+use parent qw( Amazon::API );
+
+our $VERSION = '1.2.4';
 
 our @API_METHODS = qw{
   AddPermission
@@ -39,7 +41,6 @@ sub new {
       http_method   => 'GET',
       api_methods   => \@API_METHODS,
       decode_always => 1,
-      debug         => $ENV{DEBUG} // 0,
       %options
     }
   );
