@@ -3,7 +3,9 @@ package Amazon::SecretsManager;
 use strict;
 use warnings;
 
-use parent qw/Amazon::API/;
+use parent qw( Amazon::API );
+
+our $VERSION = '1.2.4';
 
 our @API_METHODS = qw{
   CancelRotateSecret
@@ -41,7 +43,6 @@ sub new {
       service       => 'secretsmanager',
       api           => 'secretsmanager',
       api_methods   => \@API_METHODS,
-      debug         => $ENV{DEBUG} // 0,
       %options
     },
   );
